==> wasabiD-0.2.92.tgz: package/Base/Form/Input.jsx <==
/*
 create by wangzy
 date:2016-03-24
 desc:表单输入框组件
 */
require("../../sass/Base/Form/Input.scss");
var React=require("react");
var regs=require("../Lang/regs.js");
var validation=require("../Lang/validation.js");
var Select=require("./Select.jsx");
var Radio=require("./Radio.jsx");
var CheckBox=require("./CheckBox.jsx");
var SwitchButton=require("./SwitchButton.jsx");
var ComboBox=require("./ComboBox.jsx");
var alogUtil=require("../../libs/alogUtil.js");
var Input=React.createClass({
    propTypes: {
        type:React.PropTypes.oneOf([
            "text",
            "password",
            "email",
            "url",
            "date",
            "datetime",
            "daterange",
            "alpha",
            "alphanum",
            "integer",
            "number",
            "textarea",
            "select",
            "radio",
            "checkbox",
            "switch",
            "picker"
        ]),
        name:React.PropTypes.string.isRequired,
        label:React.PropTypes.string,
        placeholder:React.PropTypes.string,
        readonly:React.PropTypes.bool,
        required:React.PropTypes.bool,
        onlyline:React.PropTypes.bool,
        hide:React.PropTypes.bool,
        rows:React.PropTypes.number,
        regs:React.PropTypes.string,
        invalidTip:React.PropTypes.string,
        className:React.PropTypes.string,
        onClick:React.PropTypes.func,
        onChange:React.PropTypes.func,
        backFormHandler:React.PropTypes.func,//值改变时回传Form表单
        extraData:React.PropTypes.array,
        min:React.PropTypes.number,//最小值
        max:React.PropTypes.number,//最大值
        valueField:React.PropTypes.string,//下拉框数据字段值名称
        textField:React.PropTypes.string,//下拉框数据字段文本名称
        url:React.PropTypes.string,//后台查询地址
        backSource:React.PropTypes.string,//ajax的返回的数据源中哪个属性作为数据源,为null时直接后台返回的数据作为数据源
        data:React.PropTypes.array,
        params:React.PropTypes.object,//下拉选择面板参数
        secondUrl:React.PropTypes.string,//下拉选择面板第二层节点的后台地址,
        secondParams:React.PropTypes.object,//下拉选择面板第二层节点的后台参数
        secondParamsKey:React.PropTypes.string,//下拉选择面板第二层节点的后台参数中传递一级节点value值的参数名称
        thirdUrl:React.PropTypes.string,//下拉选择面板第三层节点的后台地址，
        thirdParams:React.PropTypes.object,//下拉选择面板第二层节点的后台参数
        thiirdParamsKey:React.PropTypes.string,//下拉选择面板第三层节点的后台参数中传递二级节点value值的参数名称

    },
    getDefaultProps:function() {
        return{
            type:"text",
            name:"",
            label:null,
            value:"",
            required:false,
            readonly:false,
            onlyline:false,
            hide:false,
            rows:5,
            regs:"",
            invalidTip:null,
            className:null,
            style:null,
            onClick:null,
            extraData:[],
            min:null,
            max:null,
            valueField:"value",
            textField:"text",
            url:null,
            backSource:null,
            data:[]
        }
    },
    getInitialState:function() {
        return{
            value:this.props.value,
            text:this.props.text,
            readonly:this.props.readonly,
            required:this.props.required,
            data:this.props.data,
            groupClass:"Form-group",
            helpShow:"none",
            helpTip:validation["required"],
            className:"",
            invalidTip:"",

        }
    },
    componentWillReceiveProps:function(nextProps) {
        this.setState({
            value: nextProps.value,
            text: nextProps.text,
            readonly: nextProps.readonly,
            required: nextProps.required,
            data: nextProps.data,
        });
        //因为父组件更新时，要重新验证一下，但是此时状态值更新没有完成，所以要将父组件新的属性传下去
        this.validate(nextProps.value,nextProps);
    },
    compoentDidMount:function() {
        this.validate(this.state.value);
    },
    changeHandler:function(event) {
        if (this.validateInput==true) {
            this.validate(event.target.value);
                   this.setState({
                       value: event.target.value,
                       text:event.target.value,
                   });
                   if (this.props.onChange != null) {
                       this.props.onChange(event.target.value);
                   }
                   //回传给表单组件
                   if (this.props.backFormHandler != null) {
                       this.props.backFormHandler(event.target.value,event.target.value,this.props.name);
                   }

        }


    },
    keyDownHandler:function(event) {//控制输入
        this.validateInput=true;
        //TODO 暂时屏蔽掉
        if(this.props.type=="integer"||this.props.type=="number")
        {
            if((event.keyCode>=65&&event.keyCode<=90))
            {
                this.validateInput=false;
            }
        }
        if(this.props.onKeyDown!=null)
        {
            this.props.onKeyDown();
        }

    },
    keyUpHandler:function() {
        this.validate(this.state.value);//验证一次，提示错误信息
        if(this.props.onKeyUp!=null)
        {
            this.props.onKeyUp();
        }
    },
    focusHandler:function() {//焦点事件
        if(this.props.onFocus!=null)
        {
            this.props.onFocus();
        }
    },
    clickHandler:function(event) {
        if(this.props.onClick!=null) {
            var model=alogUtil.clone( this.props);
            model.value=this.state.value;
            this.props.onClick(this.props.name,this.state.value,model);
        }
    },
    validate:function(value,nextProps) {
        var isvalidate=true;
        var readonly=nextProps!=undefined?nextProps.readonly:this.state.readonly;
        var required=nextProps!=undefined?nextProps.required:this.state.required;
        var helpTip="";
        if(readonly)
        {//不能直接返回，防止上一次的验证效果还在，导致无法消除

        }
        else {
        //非只读

            if (value && value != "") {
                //用户输入了值，验证有效性
                if (!this.props.regs && this.props.regs != "") {  //有正则表达式
                    isvalidate = this.props.regs.test(value);
                    if (!isvalidate) {

                        if (!this.props.invalidTip && this.props.invalidTip != "") {//用户自定义错误提示信息
                            helpTip = this.props.invalidTip;
                        }
                        else {
                            helpTip = validation["invalidTip"];
                        }
                    }
                    else {

                    }

                }
                else {
                    //没有正则表达式，则验证默认正则
                    if (regs[this.props.type]) {
                        isvalidate = regs[this.props.type].test(value);
                        if (!isvalidate) {
                            helpTip = validation[this.props.type];
                        }
                    }
                    else {

                    }
                }

                //判断大小，长度等
                if (this.props.min || this.props.min == 0) {
                    switch (this.props.type) {
                        case "text":
                            if (value.toString().length < this.props.min) {
                                isvalidate = false;
                                helpTip = "长度不能小于" + this.props.min;
                            }
                            break;
                        case "number":
                            if (value < this.props.min) {
                                isvalidate = false;
                                helpTip = "不能小于" + this.props.min;
                            }
                            break;
                        case "integer":
                            if (value < this.props.min) {
                                isvalidate = false;
                                helpTip = "不能小于" + this.props.min;
                            }
                            break;
                    }
                }
                if (this.props.max || this.props.max == 0) {
                    switch (this.props.type) {
                        case "text":
                            if (value.toString().length > this.props.max) {
                                isvalidate = false;
                                helpTip = "长度不能大于" + this.props.max;
                            }
                            break;
                        case "number":
                            if (value > this.props.max) {
                                isvalidate = false;
                                helpTip = "不能大于" + this.props.max;
                            }
                            break;
                        case "integer":
                            if (value > this.props.max) {
                                isvalidate = false;
                                helpTip = "不能大于" + this.props.max;
                            }
                            break;
                    }
                }
            }
            else {//输入没有输入
                if (required) {
                    //必填
                    isvalidate = false;//
                    helpTip = validation["required"];
                } else {
                    //认为验证有效
                }

            }
        }



        //设置样式
        if(isvalidate) {
            //验证成功
            //this.setState({
            //    groupClass: "Form-group has-success",
            //    helpShow:"none",
            //    helpTip:"",
            //
            //})
            this.setState({
                groupClass: "Form-group ",
                helpShow:"none",
                helpTip:"",

            })

        }
        else {

            this.setState({
                groupClass: "Form-group has-error",
                helpShow:"block",
                helpTip:helpTip
            });

        }
        return isvalidate;
    },
    onSelect:function(value,text,name) {//保存选中的值
               this.setState({
            value:value,
            text:text,
        });
        this.validate(value);
        if(  this.props.onSelect!=null)
        {
            this.props.onSelect(value,text,this.props.name);//回调
        }
        //回传给表单组件
        if (this.props.backFormHandler != null) {
            this.props.backFormHandler(value,text,name);
        }

    },
    getComponentData:function(name) {//只读属性，获取对应的字段的数据源
        return JSON.parse( window.localStorage.getItem(name+"data"));
    },
    renderUnInput:function(type) {//非输入框组件
        var control;
        var props=this.props;
        if(type=="select")
        {//下拉选择组件
            control=<Select ref="input" {...props } onSelect={this.onSelect} ></Select>
        }
        else  if(type=="radio")
        {//单选按钮组
            control=<Radio ref="input" {...props } onSelect={this.onSelect}></Radio>
        }
        else  if(type=="checkbox")
        {//多选择按钮组
            control=<CheckBox ref="input" {...props } onSelect={this.onSelect} ></CheckBox>
        }
        else if(type=="datetime" ||type=="date" ||type=="daterange"||type=="picker")
        {//下拉面板组件
            control=<ComboBox ref="input" {...props }  onSelect={this.onSelect}></ComboBox>
        }
        else if(type=="switch")
        {//开关
            control=<SwitchButton ref="input"  {...props} onSelect={this.onSelect}></SwitchButton>
        }

        return control;
    },
    render:function() {
        var type="text";
        var inputClass="Form-control";
        var inputstyle=this.props.style;
        if(inputstyle==null)
        {
            inputstyle={};
            inputstyle.width=(this.props.onlyline==true?"80%":null);
        }
        var props= {
            readOnly:this.state.readonly==true?"readonly":null,
            style:this.props.style,
            value:this.state.value,
            name:this.props.name,
            placeholder:this.props.placeholder,

        }
        if(this.props.className)
        {
            inputClass=inputClass+" "+this.props.className;
        }
       if(this.props.type=="text"||this.props.type=="email"
           ||this.props.type=="url"||this.props.type=="number"
           ||this.props.type=="integer"||this.props.type=="alpha"
           ||this.props.type=="alphanum")
       {//这几种类型统一为text
           type=="text";
       }
       else if(this.props.type=="password")
       {
           type="password";
       }
        else
       {
           type=this.props.type;
       }

        var control;//组件
        if(type=="text"||type=="password")
        {
            control= <input  ref="input" type={type}  className={inputClass}  {...props} onClick={this.clickHandler}
                             onChange={this.changeHandler} onKeyDown={this.keyDownHandler}
                             onKeyUp={this.keyUpHandler} onFocus={this.focusHandler}  style={inputstyle}></input>;
        }
      else  if(type=="textarea")
        {
            control=<textarea  ref="input"   className={inputClass+" "+"textarea"}   {...props}
                               rows={this.props.rows} onClick={this.clickHandler}
                               onChange={this.changeHandler} onKeyDown={this.keyDownHandler}
                               onKeyUp={this.keyUpHandler} onFocus={this.focusHandler} style={inputstyle} />;
        }
        else
        {
          control= this.renderUnInput(type);
        }
        return (
            <div className={this.state.groupClass}
                 style={{display:this.props.hide==true?"none":"inline-flex"
                 ,flexBasis:this.props.onlyline==true?"100%":"auto",width:((this.props.label&&this.props.label!="")?null:"auto")

                 }}>
                <label className="control-label" style={{
                display:(this.props.label&&this.props.label!="")?"inline":"none",
                marginLeft:(this.props.type=="textarea"?-15:0)
                }}>{this.props.label}
                </label>
                <div className="inputdiv">
                    {
                        control
                    }

                    <small className="help-block" style={{display:this.state.helpShow}}>{this.state.helpTip}</small>
                </div>
            </div>
        )
    }
});
module .exports=Input;

==> wasabiD-0.2.983.tgz: package/Base/Form/Input.jsx <==
/*
 create by wangzy
 date:2016-03-24
 desc:表单输入框组件
 */
require("../../sass/Base/Form/Input.scss");
var React=require("react");
var regs=require("../Lang/regs.js");
var validation=require("../Lang/validation.js");
var Select=require("./Select.jsx");
var Radio=require("./Radio.jsx");
var CheckBox=require("./CheckBox.jsx");
var SwitchButton=require("./SwitchButton.jsx");
var ComboBox=require("./ComboBox.jsx");
var unit=require("../../libs/unit.js");
var Input=React.createClass({
    propTypes: {
        type:React.PropTypes.oneOf([
            "text",
            "password",
            "email",
            "url",
            "date",
            "datetime",
            "daterange",
            "alpha",
            "alphanum",
            "integer",
            "number",
            "textarea",
            "select",
            "radio",
            "checkbox",
            "switch",
            "picker"
        ]),
        name:React.PropTypes.string.isRequired,
        label:React.PropTypes.string,
        placeholder:React.PropTypes.string,
        readonly:React.PropTypes.bool,
        required:React.PropTypes.bool,
        onlyline:React.PropTypes.bool,
        hide:React.PropTypes.bool,
        rows:React.PropTypes.number,
        regs:React.PropTypes.string,
        invalidTip:React.PropTypes.string,
        className:React.PropTypes.string,
        onClick:React.PropTypes.func,
        onChange:React.PropTypes.func,
        backFormHandler:React.PropTypes.func,//值改变时回传Form表单
        extraData:React.PropTypes.array,
        min:React.PropTypes.number,//最小值
        max:React.PropTypes.number,//最大值
        valueField:React.PropTypes.string,//下拉框数据字段值名称
        textField:React.PropTypes.string,//下拉框数据字段文本名称
        url:React.PropTypes.string,//后台查询地址
        backSource:React.PropTypes.string,//ajax的返回的数据源中哪个属性作为数据源,为null时直接后台返回的数据作为数据源
        data:React.PropTypes.array,
        params:React.PropTypes.object,//下拉选择面板参数
        secondUrl:React.PropTypes.string,//下拉选择面板第二层节点的后台地址,
        secondParams:React.PropTypes.object,//下拉选择面板第二层节点的后台参数
        secondParamsKey:React.PropTypes.string,//下拉选择面板第二层节点的后台参数中传递一级节点value值的参数名称
        thirdUrl:React.PropTypes.string,//下拉选择面板第三层节点的后台地址，
        thirdParams:React.PropTypes.object,//下拉选择面板第二层节点的后台参数
        thiirdParamsKey:React.PropTypes.string,//下拉选择面板第三层节点的后台参数中传递二级节点value值的参数名称

    },
    getDefaultProps:function() {
        return{
            type:"text",
            name:"",
            label:null,
            value:"",
            required:false,
            readonly:false,
            onlyline:false,
            hide:false,
            rows:5,
            regs:"",
            invalidTip:null,
            className:null,
            style:null,
            onClick:null,
            extraData:[],
            min:null,
            max:null,
            valueField:"value",
            textField:"text",
            url:null,
            backSource:null,
            data:[]
        }
    },
    getInitialState:function() {
        return{
            value:this.props.value,
            text:this.props.text,
            readonly:this.props.readonly,
            required:this.props.required,
            data:this.props.data,
            groupClass:"Form-group",
            helpShow:"none",
            helpTip:validation["required"],
            className:"",
            invalidTip:"",

        }
    },
    componentWillReceiveProps:function(nextProps) {
        this.setState({
            value: nextProps.value,
            text: nextProps.text,
            readonly: nextProps.readonly,
            required: nextProps.required,
            data: nextProps.data,
        });
        //因为父组件更新时，要重新验证一下，但是此时状态值更新没有完成，所以要将父组件新的属性传下去
        this.validate(nextProps.value,nextProps);
    },
    compoentDidMount:function() {
        this.validate(this.state.value);
    },
    changeHandler:function(event) {
        if (this.validateInput==true) {
            this.validate(event.target.value);
                   this.setState({
                       value: event.target.value,
                       text:event.target.value,
                   });
                   if (this.props.onChange != null) {
                       this.props.onChange(event.target.value);
                   }
                   //回传给表单组件
                   if (this.props.backFormHandler != null) {
                       this.props.backFormHandler(event.target.value,event.target.value,this.props.name);
                   }

        }


    },
    keyDownHandler:function(event) {//控制输入
        this.validateInput=true;
        //TODO 暂时屏蔽掉
        if(this.props.type=="integer"||this.props.type=="number")
        {
            if((event.keyCode>=65&&event.keyCode<=90))
            {
                this.validateInput=false;
            }
        }
        if(this.props.onKeyDown!=null)
        {
            this.props.onKeyDown();
        }

    },
    keyUpHandler:function() {
        this.validate(this.state.value);//验证一次，提示错误信息
        if(this.props.onKeyUp!=null)
        {
            this.props.onKeyUp();
        }
    },
    focusHandler:function() {//焦点事件
        if(this.props.onFocus!=null)
        {
            this.props.onFocus();
        }
    },
    clickHandler:function(event) {
        if(this.props.onClick!=null) {
            var model=unit.clone( this.props);
            model.value=this.state.value;
            this.props.onClick(this.props.name,this.state.value,model);
        }
    },
    validate:function(value,nextProps) {
        var isvalidate=true;
        var readonly=nextProps!=undefined?nextProps.readonly:this.state.readonly;
        var required=nextProps!=undefined?nextProps.required:this.state.required;
        var helpTip="";
        if(readonly)
        {//不能直接返回，防止上一次的验证效果还在，导致无法消除

        }
        else {
        //非只读

            if (value && value != "") {
                //用户输入了值，验证有效性
                if (!this.props.regs && this.props.regs != "") {  //有正则表达式
                    isvalidate = this.props.regs.test(value);
                    if (!isvalidate) {

                        if (!this.props.invalidTip && this.props.invalidTip != "") {//用户自定义错误提示信息
                            helpTip = this.props.invalidTip;
                        }
                        else {
                            helpTip = validation["invalidTip"];
                        }
                    }
                    else {

                    }

                }
                else {
                    //没有正则表达式，则验证默认正则
                    if (regs[this.props.type]) {
                        isvalidate = regs[this.props.type].test(value);
                        if (!isvalidate) {
                            helpTip = validation[this.props.type];
                        }
                    }
                    else {

                    }
                }

                //判断大小，长度等
                if (this.props.min || this.props.min == 0) {
                    switch (this.props.type) {
                        case "text":
                            if (value.toString().length < this.props.min) {
                                isvalidate = false;
                                helpTip = "长度不能小于" + this.props.min;
                            }
                            break;
                        case "number":
                            if (value < this.props.min) {
                                isvalidate = false;
                                helpTip = "不能小于" + this.props.min;
                            }
                            break;
                        case "integer":
                            if (value < this.props.min) {
                                isvalidate = false;
                                helpTip = "不能小于" + this.props.min;
                            }
                            break;
                    }
                }
                if (this.props.max || this.props.max == 0) {
                    switch (this.props.type) {
                        case "text":
                            if (value.toString().length > this.props.max) {
                                isvalidate = false;
                                helpTip = "长度不能大于" + this.props.max;
                            }
                            break;
                        case "number":
                            if (value > this.props.max) {
                                isvalidate = false;
                                helpTip = "不能大于" + this.props.max;
                            }
                            break;
                        case "integer":
                            if (value > this.props.max) {
                                isvalidate = false;
                                helpTip = "不能大于" + this.props.max;
                            }
                            break;
                    }
                }
            }
            else {//输入没有输入
                if (required) {
                    //必填
                    isvalidate = false;//
                    helpTip = validation["required"];
                } else {
                    //认为验证有效
                }

            }
        }



        //设置样式
        if(isvalidate) {
            //验证成功
            //this.setState({
            //    groupClass: "Form-group has-success",
            //    helpShow:"none",
            //    helpTip:"",
            //
            //})
            this.setState({
                groupClass: "Form-group ",
                helpShow:"none",
                helpTip:"",

            })

        }
        else {

            this.setState({
                groupClass: "Form-group has-error",
                helpShow:"block",
                helpTip:helpTip
            });

        }
        return isvalidate;
    },
    onSelect:function(value,text,name) {//保存选中的值
               this.setState({
            value:value,
            text:text,
        });
        this.validate(value);
        if(  this.props.onSelect!=null)
        {
            this.props.onSelect(value,text,this.props.name);//回调
        }
        //回传给表单组件
        if (this.props.backFormHandler != null) {
            this.props.backFormHandler(value,text,name);
        }

    },
    getComponentData:function(name) {//只读属性，获取对应的字段的数据源
        return JSON.parse( window.localStorage.getItem(name+"data"));
    },
    renderUnInput:function(type) {//非输入框组件
        var control;
        var props=this.props;
        if(type=="select")
        {//下拉选择组件
            control=<Select ref="input" {...props } onSelect={this.onSelect} ></Select>
        }
        else  if(type=="radio")
        {//单选按钮组
            control=<Radio ref="input" {...props } onSelect={this.onSelect}></Radio>
        }
        else  if(type=="checkbox")
        {//多选择按钮组
            control=<CheckBox ref="input" {...props } onSelect={this.onSelect} ></CheckBox>
        }
        else if(type=="datetime" ||type=="date" ||type=="daterange"||type=="picker")
        {//下拉面板组件
            control=<ComboBox ref="input" {...props }  onSelect={this.onSelect}></ComboBox>
        }
        else if(type=="switch")
        {//开关
            control=<SwitchButton ref="input"  {...props} onSelect={this.onSelect}></SwitchButton>
        }

        return control;
    },
    render:function() {
        var type="text";
        var inputClass="Form-control";
        var inputstyle=this.props.style;
        if(inputstyle==null)
        {
            inputstyle={};
            inputstyle.width=(this.props.onlyline==true?"80%":null);
        }
        var props= {
            readOnly:this.state.readonly==true?"readonly":null,
            style:this.props.style,
            value:this.state.value,
            name:this.props.name,
            placeholder:this.props.placeholder,

        }
        if(this.props.className)
        {
            inputClass=inputClass+" "+this.props.className;
        }
       if(this.props.type=="text"||this.props.type=="email"
           ||this.props.type=="url"||this.props.type=="number"
           ||this.props.type=="integer"||this.props.type=="alpha"
           ||this.props.type=="alphanum")
       {//这几种类型统一为text
           type=="text";
       }
       else if(this.props.type=="password")
       {
           type="password";
       }
        else
       {
           type=this.props.type;
       }

        var control;//组件
        if(type=="text"||type=="password")
        {
            control= <input  ref="input" type={type}  className={inputClass}  {...props} onClick={this.clickHandler}
                             onChange={this.changeHandler} onKeyDown={this.keyDownHandler}
                             onKeyUp={this.keyUpHandler} onFocus={this.focusHandler}  style={inputstyle}></input>;
        }
      else  if(type=="textarea")
        {
            control=<textarea  ref="input"   className={inputClass+" "+"textarea"}   {...props}
                               rows={this.props.rows} onClick={this.clickHandler}
                               onChange={this.changeHandler} onKeyDown={this.keyDownHandler}
                               onKeyUp={this.keyUpHandler} onFocus={this.focusHandler} style={inputstyle} />;
        }
        else
        {
          control= this.renderUnInput(type);
        }
        return (
            <div className={this.state.groupClass}
                 style={{display:this.props.hide==true?"none":"inline-flex"
                 ,flexBasis:this.props.onlyline==true?"100%":"auto",width:((this.props.label&&this.props.label!="")?null:"auto")

                 }}>
                <label className="control-label" style={{
                display:(this.props.label&&this.props.label!="")?"inline":"none",
                marginLeft:(this.props.type=="textarea"?-15:0)
                }}>{this.props.label}
                </label>
                <div className="inputdiv">
                    {
                        control
                    }

                    <small className="help-block" style={{display:this.state.helpShow}}>{this.state.helpTip}</small>
                </div>
            </div>
        )
    }
});
module .exports=Input;
